Structs
- Begin
Search Index - A version of begin search spec that finds the index indicating where to start search for keys based on an index.
- Begin
Search Keyword - A version of begin search spec that finds the index indicating where to start search for keys based on a keyword.
- Command
ArgFlags - Command
Info - A struct represent a CommandInfo
- Find
Keys Num - A version of find keys base on some argument representing the number of keys
- Find
Keys Range - A version of find keys base on range.
- KeySpec
- A struct that specify how to find keys from a command. It is devided into 2 parts:
- KeySpec
Flags - Key spec flags
- Redis
Module Command Arg
Enums
- Begin
Search - This struct represents how Redis should start looking for keys. There are 2 possible options:
- Find
Keys - After Redis finds the location from where it needs to start looking for keys, Redis will start finding keys base on the information in this enum. There are 2 possible options: