get_keyspace_notification_flags_all

Function get_keyspace_notification_flags_all 

pub fn get_keyspace_notification_flags_all() -> NotifyEvent
Returns all the available notification flags for key-space notifications.

Safety

This function is safe to use as it doesn’t perform any work with the RedisModuleCtx pointer except for passing it to the redis server.

Panics

Panics when the RedisModule_GetKeyspaceNotificationFlagsAll is unavailable.