Struct redis_module::raw::KeyMode [−][src]
pub struct KeyMode { /* fields omitted */ }Implementations
impl KeyMode[src]
impl KeyMode[src]pub const READ: KeyMode[src]
pub const WRITE: KeyMode[src]
pub const fn empty() -> KeyMode[src]
Returns an empty set of flags
pub const fn all() -> KeyMode[src]
Returns the set containing all flags.
pub const fn bits(&self) -> c_int[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: c_int) -> Option<KeyMode>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: c_int) -> KeyMode[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: c_int) -> KeyMode[src]
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub const fn intersects(&self, other: KeyMode) -> bool[src]
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: KeyMode) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: KeyMode)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: KeyMode)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: KeyMode)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: KeyMode, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.